@@ -1,5 +1,5 @@
 import copy
-from sys import getswitchinterval
+from sys import getswitchinterval, exit
 
 from jsonrpcserver import async_dispatch
 import json
@@ -8,7 +8,6 @@ import websockets
 import aiohttp
 from aiohttp import web
 
-from gear.multi_app import MultiApp
 from .rpc import make_version
 from json.decoder import JSONDecodeError
 from .meter.account import (
@@ -129,6 +128,7 @@ async def websocket_handler(request):
                                
                                 res = await handleRequest( json.loads(msg.data), False, False)
                                 copy_obj = copy.deepcopy(json.loads(res))
+                                copy_obj["result"]["timestamp"] = hex(copy_obj["result"]["timestamp"])
                                 # convert the subscription object into an appropriate response
                                 res_obj = {"jsonrpc": copy_obj["jsonrpc"] , "method":"eth_subscription", "params":{"result":copy_obj["result"], "subscription":"0x00640404976e52864c3cfd120e5cc28aac3f644748ee6e8be185fb780cdfd827"}}
                                 await ws.send_str(json.dumps(res_obj))
@@ -215,8 +215,10 @@ def get_ws_app(host, port, endpoint, keystore, passcode, log, debug, chainid):
 
 async def run_server(host, port, endpoint, keystore, passcode, log, debug, chainid):
     http_app = get_http_app(host, port, endpoint, keystore, passcode, log, debug, chainid)
-    ws_app = get_ws_app(host, port, endpoint, keystore, passcode, log, debug, chainid)
 
+    if http_app == None:
+        print("Could not start http server due to connection problem, check your --endpoint settings")
+        exit(-1)
     print('Starting http server')
     http_runner = web.AppRunner(http_app)
     await http_runner.setup()
@@ -224,6 +226,10 @@ async def run_server(host, port, endpoint, keystore, passcode, log, debug, chain
     await http.start()
     print("HTTP Listening on %s:%s" % (host, port))
 
+    ws_app = get_ws_app(host, port, endpoint, keystore, passcode, log, debug, chainid)
+    if ws_app == None:
+        print("Could not start http server due to connection problem, check your --endpoint settings")
+        exit(-1)
     print('Starting ws server')
     ws_runner = web.AppRunner(ws_app)
     await ws_runner.setup()
